==> sdk-1.1.9-sources.jar: org/starcoin/bean/UncleBlock.java <==
/*
 * Copyright 2002-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.starcoin.bean;


import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;

@JSONType(naming = PropertyNamingStrategy.SnakeCase)
public class UncleBlock {
    private BlockHeader header;
    @JSONField(name = "uncle_block_number")
    private long uncleBlockNumber;

    public BlockHeader getHeader() {
        return header;
    }

    public void setHeader(BlockHeader header) {
        this.header = header;
    }

    public long getUncleBlockNumber() {
        return uncleBlockNumber;
    }

    public void setUncleBlockNumber(long uncleBlockNumber) {
        this.uncleBlockNumber = uncleBlockNumber;
    }

    @Override
    public String toString() {
        return "UncleBlock{" +
                "header=" + header +
                ", uncleBlockNumber=" + uncleBlockNumber +
                '}';
    }
}

==> sdk-1.2.6-sources.jar: org/starcoin/bean/UncleBlock.java <==
/*
 * Copyright 2002-2021 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.starcoin.bean;


import com.alibaba.fastjson.PropertyNamingStrategy;
import com.alibaba.fastjson.annotation.JSONField;
import com.alibaba.fastjson.annotation.JSONType;

@JSONType(naming = PropertyNamingStrategy.SnakeCase)
public class UncleBlock extends Base {
    private BlockHeader header;
    @JSONField(name = "uncle_block_number")
    private long uncleBlockNumber;

    public BlockHeader getHeader() {
        return header;
    }

    public void setHeader(BlockHeader header) {
        this.header = header;
    }

    public long getUncleBlockNumber() {
        return uncleBlockNumber;
    }

    public void setUncleBlockNumber(long uncleBlockNumber) {
        this.uncleBlockNumber = uncleBlockNumber;
    }

    @Override
    public String toString() {
        return "UncleBlock{" +
                "header=" + header +
                ", uncleBlockNumber=" + uncleBlockNumber +
                '}';
    }
}
